//
//  GetCategoryView.swift
//  SampleApp
//
//  Created by Zay Yar Htun on 7/19/23.
//  Copyright © 2023 David Zhang. All rights reserved.
//

import SwiftUI
import AmitySDK

struct GetCategoryView: View {
    @State private var categoryId: String = ""
    @StateObject var viewModel = GetCategoryViewModel()
    
    var body: some View {
        Form {
            TextField("Enter Category Id", text: $categoryId)
            
            Section {
                Button {
                    guard !categoryId.isEmpty else { return }
                    
                    viewModel.getCategory(id: categoryId)
                    
                } label: {
                    HStack {
                        Spacer()
                        Text("Get Category")
                        Spacer()
                    }
                }
            }
            
            Section(header: Text("Here you will see result received from sdk")) {
                VStack(alignment: .leading) {
                    Text("Result")
                        .font(.system(size: 18))
                        .fontWeight(.bold)
                        .padding(.bottom, 12)
                    Text(viewModel.result)
                }
            }
        }
        .navigationTitle("Get Category")
    }
}

struct GetCategoryView_Previews: PreviewProvider {
    static var previews: some View {
        GetCategoryView()
    }
}

class GetCategoryViewModel: ObservableObject {
    
    @Published var result: String = ""
    
    var token: AmityNotificationToken?
    var communityRepo = AmityCommunityRepository(client: AmityManager.shared.client!)
    
    
    func getCategory(id: String) {
        token = communityRepo.getCategory(withId: id).observe { [weak self] liveObject, error in
            guard let weakSelf = self else {
                return
            }
            
            if error != nil {
                weakSelf.result = ""
                weakSelf.token?.invalidate()
                return
            }
            
            if let object = liveObject.object {
                weakSelf.result = "Name:\n\(object.name)\n\nId:\n\(object.categoryId)\n\nAvatar:\n\(object.avatarFileId)"
            }
        }
    }
}
