//
//  ContentSettingsView.swift
//  SampleApp
//
//  Created by Nontapat Siengsanor on 2/8/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//

import AmitySDK
import SwiftUI

struct ContentSettingsView: View {
    
    weak var client: AmityClient!
    @State private var contentDetail: String = ""
    
    var body: some View {
        VStack {
            Text(contentDetail)
            
        }.onAppear {
            fetchContentSettings()
        }
    }
    
    private func fetchContentSettings() {
        Task {
            let settings = try? await client?.getContentSettings()
            
            contentDetail = settings?.description ?? ""
        }
    }
}

struct ContentSettingsView_Previews: PreviewProvider {
    static var previews: some View {
        ContentSettingsView()
    }
}

extension AmityContentSettings {
    
    var description: String {
        var desc = ""
        
        if let post = post {
            desc += "feedType: post\n"
            desc += post.description
            desc += "\n"
        }
        
        if let message = message {
            desc += "feedType: message\n"
            desc += message.description
        }
        
        return desc
    }
    
}

extension AmityFeedSettings {
    var description: String {
        var desc = ""
        if let textSettings = textSettings {
            desc += "⎮ contentType: text\n"
            desc += "\(textSettings.description)\n"
            desc += "⎮\n"
        }
        if let videoSettings = videoSettings {
            desc += "⎮ contentType: video\n"
            desc += "\(videoSettings.description)\n"
            desc += "\n"
        }
        return desc
    }
}

extension AmityTextContentSettings {
    var description: String {
        return "⎮ → allowed: \(allowed)"
    }
}

extension AmityVideoContentSettings {
    
    var description: String {
        return """
        ⎮ → allowed: \(allowed)
        ⎮ → maxDurationSecond: \(maxDurationSeconds)
        ⎮ → minResolution: \(transcodeConfig.minResolution)
        ⎮ → maxResolution: \(transcodeConfig.maxResolution)
        """
    }
}
